import tkinter as tk
from tkinter import messagebox
import sqlite3

# Connect to (or create) the myDB.db database and create the user table if it doesn't exist.
conn = sqlite3.connect("myDB.db")
cursor = conn.cursor()
cursor.execute('''
CREATE TABLE IF NOT EXISTS user (.
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    username TEXT UNIQUE,
    password TEXT,
    fullname TEXT,
    email TEXT
)
''')
conn.commit()

# ---------------------------
# Main Login GUI Setup
# ---------------------------
root = tk.Tk()
root.title("Login")

# Username label and entry
tk.Label(root, text="Username:").grid(row=0, column=0, padx=5, pady=5)
username_entry = tk.Entry(root)
username_entry.grid(row=0, column=1, padx=5, pady=5)

# Password label and entry
tk.Label(root, text="Password:").grid(row=1, column=0, padx=5, pady=5)
password_entry = tk.Entry(root, show="*")
password_entry.grid(row=1, column=1, padx=5, pady=5)

def login():
    """Checks login credentials against the database."""
    username = username_entry.get()
    password = password_entry.get()
    cursor.execute("SELECT * FROM user WHERE username = ? AND password = ?", (username, password))
    result = cursor.fetchone()
    if result:
        messagebox.showinfo("Login", "Login successful!")
    else:
        messagebox.showwarning("Login", "Invalid credentials.\nIf you are not registered, please click Register.")

def open_register():
    """Opens a new window to capture new user details and register the user."""
    reg_window = tk.Toplevel(root)
    reg_window.title("Register")
    
    # Four text fields: username, password, full name, and email
    tk.Label(reg_window, text="Username:").grid(row=0, column=0, padx=5, pady=5)
    reg_username = tk.Entry(reg_window)
    reg_username.grid(row=0, column=1, padx=5, pady=5)
    
    tk.Label(reg_window, text="Password:").grid(row=1, column=0, padx=5, pady=5)
    reg_password = tk.Entry(reg_window, show="*")
    reg_password.grid(row=1, column=1, padx=5, pady=5)
    
    tk.Label(reg_window, text="Full Name:").grid(row=2, column=0, padx=5, pady=5)
    reg_fullname = tk.Entry(reg_window)
    reg_fullname.grid(row=2, column=1, padx=5, pady=5)
    
    tk.Label(reg_window, text="Email:").grid(row=3, column=0, padx=5, pady=5)
    reg_email = tk.Entry(reg_window)
    reg_email.grid(row=3, column=1, padx=5, pady=5)
    
    def register_user():
        """Insert the new user record into the database."""
        username = reg_username.get()
        password = reg_password.get()
        fullname = reg_fullname.get()
        email = reg_email.get()
        
        if username and password and fullname and email:
            try:
                cursor.execute("INSERT INTO user (username, password, fullname, email) VALUES (?, ?, ?, ?)",
                               (username, password, fullname, email))
                conn.commit()
                messagebox.showinfo("Registration", "Registration successful!")
                reg_window.destroy()
            except sqlite3.IntegrityError:
                messagebox.showerror("Registration", "Username already exists!\nPlease choose another username.")
        else:
            messagebox.showwarning("Registration", "All fields are required!")
    
    # Two buttons: OK (to register) and Cancel (to abort registration)
    tk.Button(reg_window, text="OK", command=register_user).grid(row=4, column=0, padx=5, pady=5)
    tk.Button(reg_window, text="Cancel", command=reg_window.destroy).grid(row=4, column=1, padx=5, pady=5)

# Main window buttons for Login and Register
tk.Button(root, text="Login", command=login).grid(row=2, column=0, padx=5, pady=5)
tk.Button(root, text="Register", command=open_register).grid(row=2, column=1, padx=5, pady=5)

root.mainloop()
conn.close()
